"""Vicoa constants and default configuration values."""

# Default API endpoint
DEFAULT_API_URL = "https://api.vicoa.ai:8443"

# Default frontend URL for authentication
DEFAULT_AUTH_URL = "https://vicoa.ai"

# Default relay URL
DEFAULT_RELAY_URL = "wss://relay.vicoa.ai/agent"
